@@ -71,8 +71,15 @@ void SortColorizeProxyModel::setFilters(const std::vector<QSharedPointer<const F
     if (m_matchers == matchers) {
         return;
     }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+    beginFilterChange();
+#endif
     m_matchers = matchers;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+    endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
     invalidateFilter();
+#endif
 }
 
 QVariant SortColorizeProxyModel::data(const QModelIndex &idx, int role) const
@@ -296,7 +303,7 @@ static int maxDateColumnWidth(const QFontMetrics &fm)
     int width = 0;
     QDateTime date(QDate::currentDate(), QTime(23, 59));
     for (int x = 0; x < 10; ++x, date = date.addDays(-1)) {
-        QString txt = QLatin1Char(' ') + QLocale().toString(date, QLocale::ShortFormat) + QLatin1Char(' ');
+        QString txt = QLatin1Char(' ') + QLocale().toString(date, QLocale::ShortFormat) + u' ';
         width = qMax(width, fm.boundingRect(txt).width());
     }
     return width;
