@@ -10,6 +10,7 @@
 #include "akregator_debug.h"
 #include "akregatorconfig.h"
 #include "articleviewerwebenginepage.h"
+#include "config-akregator.h"
 #include "webengine/urlhandlerwebenginemanager.h"
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
@@ -155,7 +156,7 @@ void ArticleViewerWebEngine::paintAboutScreen(const QString &templateName, const
     GrantleeTheme::ThemeManager manager(QStringLiteral("splashPage"), QStringLiteral("splash.theme"), nullptr, QStringLiteral("messageviewer/about/"));
     GrantleeTheme::Theme theme = manager.theme(QStringLiteral("default"));
     if (theme.isValid()) {
-        setHtml(theme.render(templateName, data, QByteArrayLiteral("akregator")), QUrl::fromLocalFile(theme.absolutePath() + QLatin1Char('/')));
+        setHtml(theme.render(templateName, data, QByteArrayLiteral("akregator")), QUrl::fromLocalFile(theme.absolutePath() + u'/'));
     } else {
         qCDebug(AKREGATOR_LOG) << "Theme error: failed to find splash theme";
     }
@@ -304,7 +305,7 @@ void ArticleViewerWebEngine::slotWebHitFinished(const WebEngineViewer::WebHitTes
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("tab_unmute")));
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("find_in_messages")));
-#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("speak_text")));
 #endif
