@@ -30,7 +30,7 @@ public:
 
     void setTargetList(const QWeakPointer<FeedList> &feedList);
 
-    enum RootFolderOption {
+    enum class RootFolderOption : uint8_t {
         None,
         Auto,
         Ask,
@@ -44,8 +44,6 @@ public:
 private:
     void doStart() override;
     void doAbort() override;
-
-private:
     friend class ImportFeedListCommandPrivate;
     std::unique_ptr<ImportFeedListCommandPrivate> const d;
 };
