@@ -8,8 +8,8 @@
 
 #pragma once
 
+#include <QList>
 #include <QSortFilterProxyModel>
-#include <QVector>
 
 namespace Akregator
 {
@@ -24,16 +24,16 @@ public:
     explicit FilterColumnsProxyModel(QObject *parent = nullptr);
 
     void setColumnEnabled(int col, bool enabled = true);
-    Q_REQUIRED_RESULT bool isColumnEnabled(int col) const;
+    [[nodiscard]] bool isColumnEnabled(int col) const;
 
-    Q_REQUIRED_RESULT Mode mode() const;
+    [[nodiscard]] Mode mode() const;
     void setMode(Mode mode);
 
 private:
-    Q_REQUIRED_RESULT bool filterAcceptsColumn(int source_column, const QModelIndex &source_parent) const override;
+    [[nodiscard]] bool filterAcceptsColumn(int source_column, const QModelIndex &source_parent) const override;
 
 private:
-    QVector<bool> m_columnStates;
+    QList<bool> m_columnStates;
     int m_vecSize = 0;
     Mode m_mode = Whitelist;
 };
